@@ -5,6 +5,36 @@ from laboro.validator import Validator
 
 
 class Module:
+  """The ``laboro.module.Module`` class is the base class from which each **Laboro** module must be derived from.
+
+  It provides the ``@laboro_method`` decorator which must decorate any **public method** of a derived module.
+
+  ..  code-block:: python
+
+        from laboro.module import Module
+
+        class MyModule(Module):
+          def __init__(self, context, args):
+            super().__init__(filepath=__file__, context=context, args=args)
+
+        @Module.laboro_method
+        def my_public_method(self, arg1, arg2):
+          self._private_method(arg1)
+
+        def _my_private_method(self, arg1):
+          <do thing>
+
+  Arguments:
+    filepath: The file path of the module. From the derived class scope, it should be ``__file__``. The ``filepath`` arguement is used to retrieve the module *YAML* specification file.
+    context: The ``laboro.context.Context`` associated with the ``laboro.workflow.Workflow`` instance instantiating the module. The ``context`` will be automatically provided by the workflow.
+    args: A kwargs representing the module instance arguments.
+
+  Returns:
+    ``laboro.module.Module``
+
+  Raises:
+    laboro.error.LaboroError: When the ``args`` kwargs does not validate against the module specification or when the module specification does not validate the meta module specification.
+  """
   def __init__(self, filepath, context, args=None):
     self.filepath = filepath
     self.context = context
@@ -14,6 +44,8 @@ class Module:
 
   @staticmethod
   def laboro_method(func):
+    """The ``@laboro.module.Module.laboro_method`` decorator provides the way to validate the module methods arguments against the module method specification. All module derived from the `laboro.module.Module`` **must** decorate all their **public methods**.
+    """
     def wrapper(self, *args, **kwargs):
       if len(args) > 1:
         logging.error("Using method with args instead of kwargs !")
