@@ -7,15 +7,9 @@ from laboro.error import LaboroError
 
 
 class Validator:
-  """The ``laboro.Validator`` object purpose is to validate specification and arguments.
+  """The ``laboro.validator.Validator`` object purpose is to validate `json` object against `jsonschema` specification given as `YAML` files.
 
-  This object is instantiated by some **Laboro** core components and is not intended to be used directly.
-
-  Arguments:
-    ``filepath``: A string specifying the filepath of **the base module**. The expected value is the base module ``__file__`` attribute value. The specification will be search as ``object.yml`` in the ``specification`` directory situated at the same level of ``filepath``.
-
-  Raises:
-    ``laboro.error.Error``: When the **Laboro** base module specification file is not found or not a valid *YAML* file.
+  This object is instantiated by some **Laboro** core components and is **not intended to be used directly**.
   """
 
   def _load_file(self, filepath):
@@ -40,10 +34,10 @@ class Validator:
     Arguments:
     ``schema``: A file path to a *YAML* representation of a `jsonschema` representing the schema against which the ``instance`` should be validated.
 
-    ``instance``: A file path to a *YAML* representation of a `jsonschema` representing the instance to validate.
+    ``instance``: A file path to a *YAML* representation of a `json` representing the instance to validate.
 
     Raises:
-      ``laboro.error.Error``: Whenever the schema or the instance file can't be loaded or are not valid *YAML* files. Error is also raised when the given ``instance`` is not valid.
+      ``laboro.error.Error``: Whenever the schema or the instance file can't be loaded or are not valid *YAML* files. Error is also raised when the given ``schema`` is not a valid `jsonschema` or when ``instance`` can not validate against the given ``schema`.
     """
     try:
       schema_yml = self._load_file(schema)
@@ -62,10 +56,19 @@ class Validator:
       logging.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
-  def validate_data(self, specification, data):
+  def validate_data(self, schema, data):
+    """Validate the specified `data` dict against the `YAML` representation of a `jsonschema`.
+
+    Arguments:
+      schema: A file path to a *YAML* representation of a `jsonschema`
+      schema: A dict representing the instance to validate.
+
+    Raises:
+      ``laboro.error.Error``: Whenever the schema file can't be loaded or is not valid *YAML* files. Error is also raised when the given ``schema`` is not a valid `jsonschema` or when ``data`` can not validate against the given ``schema`.
+    """
     try:
-      specification_yml = self._load_file(specification)
-      validate(instance=data, schema=specification_yml)
+      schema_yml = self._load_file(schema)
+      validate(instance=data, schema=schema_yml)
     except ValidationError as err:
       err_msg = str(err).split("\n")[0]
       msg = f"[InvalidDataError] {err_msg}"
@@ -73,6 +76,15 @@ class Validator:
       raise LaboroError(msg) from err
 
   def validate_method_args(self, method, args):
+    """Validate the method arguments against the method specification.
+
+    Arguments:
+      method: A string representation of a `jsonschema` describing the method specification.
+      args: A dict representing the method argument and their values.
+
+    Raises:
+      ``laboro.error.LaboroError``: When the given ``args`` does not validate against the specification.
+    """
     try:
       validate(instance=args, schema=method)
       if isinstance(args, dict):
@@ -101,6 +113,15 @@ class Validator:
       raise LaboroError(msg) from err
 
   def validate_obj_args(self, specification, args):
+    """Validate the instantiation arguments against the object specification.
+
+    Arguments:
+      specification: A file path to a *YAML* representation of a `jsonschema` representing the schema against which the ``args`` should be validated.
+      args: A dict representing the object instantiation argument and their values.
+
+    Raises:
+      ``laboro.error.LaboroError``: When the given ``args`` does not validate against the specification.
+    """
     try:
       specification_yml = self._load_file(specification)
       validate(instance=args, schema=specification_yml)
