@@ -1,18 +1,17 @@
 import os
-import re
 import shutil
 import logging
 from laboro.error import LaboroError
 
 
 class Workspace:
-  """The ``laboro.workspace.Workspace`` object manages the workflow and instances workspaces.
+  """The ``laboro.workspace.Workspace`` object manages the `laboro.workflow.`workflow`` instance workspace.
 
-  The workflow workspace is a directory named after the workflow name within the Laboro global temp directory.
+  The workflow workspace is a directory named after the workflow name within the **Laboro** global ``workspacedir`` directory.
 
-  Instances workspaces are a workflow workspace sub-directory named after the workflow session.
+  Each workflow execution has its own sub-directory  named after the workflow session.
 
-  A ``Workspace`` instance is used to store files and data within the workflow execution.
+  A ``Workspace`` instance is used to store files within the workflow execution.
 
   Arguments:
     workspacedir: A string defining the directory where all workspaces are stored.
